# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/PositionControl.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_PositionControl(object):
    def setupUi(self, PositionControl):
        PositionControl.setObjectName("PositionControl")
        PositionControl.resize(415, 495)
        self.verticalLayout = QtWidgets.QVBoxLayout(PositionControl)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gb_pan = QtWidgets.QGroupBox(PositionControl)
        self.gb_pan.setAlignment(QtCore.Qt.AlignCenter)
        self.gb_pan.setFlat(False)
        self.gb_pan.setCheckable(False)
        self.gb_pan.setObjectName("gb_pan")
        self.gridLayout = QtWidgets.QGridLayout(self.gb_pan)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.lb_min_pan = QtWidgets.QLabel(self.gb_pan)
        self.lb_min_pan.setObjectName("lb_min_pan")
        self.gridLayout.addWidget(self.lb_min_pan, 0, 0, 1, 1)
        self.sl_pos_pan = QtWidgets.QSlider(self.gb_pan)
        self.sl_pos_pan.setOrientation(QtCore.Qt.Horizontal)
        self.sl_pos_pan.setObjectName("sl_pos_pan")
        self.gridLayout.addWidget(self.sl_pos_pan, 1, 0, 1, 6)
        self.lb_max_pan = QtWidgets.QLabel(self.gb_pan)
        self.lb_max_pan.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lb_max_pan.setObjectName("lb_max_pan")
        self.gridLayout.addWidget(self.lb_max_pan, 0, 5, 1, 1)
        self.sb_move_pan = QtWidgets.QDoubleSpinBox(self.gb_pan)
        self.sb_move_pan.setObjectName("sb_move_pan")
        self.gridLayout.addWidget(self.sb_move_pan, 0, 3, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 0, 4, 1, 1)
        self.label = QtWidgets.QLabel(self.gb_pan)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 2, 1, 1)
        self.verticalLayout.addWidget(self.gb_pan)
        self.gb_tilt = QtWidgets.QGroupBox(PositionControl)
        self.gb_tilt.setAlignment(QtCore.Qt.AlignCenter)
        self.gb_tilt.setObjectName("gb_tilt")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.gb_tilt)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        spacerItem2 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem2, 0, 1, 1, 1)
        self.sb_move_tilt = QtWidgets.QDoubleSpinBox(self.gb_tilt)
        self.sb_move_tilt.setObjectName("sb_move_tilt")
        self.gridLayout_2.addWidget(self.sb_move_tilt, 0, 3, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.gb_tilt)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 0, 2, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem3, 0, 4, 1, 1)
        self.lb_min_tilt = QtWidgets.QLabel(self.gb_tilt)
        self.lb_min_tilt.setObjectName("lb_min_tilt")
        self.gridLayout_2.addWidget(self.lb_min_tilt, 0, 0, 1, 1)
        self.sl_pos_tilt = QtWidgets.QSlider(self.gb_tilt)
        self.sl_pos_tilt.setOrientation(QtCore.Qt.Horizontal)
        self.sl_pos_tilt.setObjectName("sl_pos_tilt")
        self.gridLayout_2.addWidget(self.sl_pos_tilt, 1, 0, 1, 6)
        self.lb_max_tilt = QtWidgets.QLabel(self.gb_tilt)
        self.lb_max_tilt.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lb_max_tilt.setObjectName("lb_max_tilt")
        self.gridLayout_2.addWidget(self.lb_max_tilt, 0, 5, 1, 1)
        self.verticalLayout.addWidget(self.gb_tilt)
        self.gb_zoom = QtWidgets.QGroupBox(PositionControl)
        self.gb_zoom.setAlignment(QtCore.Qt.AlignCenter)
        self.gb_zoom.setObjectName("gb_zoom")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.gb_zoom)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_6 = QtWidgets.QLabel(self.gb_zoom)
        self.label_6.setObjectName("label_6")
        self.gridLayout_3.addWidget(self.label_6, 0, 2, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem4, 0, 4, 1, 1)
        self.lb_max_zoom = QtWidgets.QLabel(self.gb_zoom)
        self.lb_max_zoom.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lb_max_zoom.setObjectName("lb_max_zoom")
        self.gridLayout_3.addWidget(self.lb_max_zoom, 0, 5, 1, 1)
        self.sl_pos_zoom = QtWidgets.QSlider(self.gb_zoom)
        self.sl_pos_zoom.setOrientation(QtCore.Qt.Horizontal)
        self.sl_pos_zoom.setObjectName("sl_pos_zoom")
        self.gridLayout_3.addWidget(self.sl_pos_zoom, 1, 0, 1, 6)
        self.lb_min_zoom = QtWidgets.QLabel(self.gb_zoom)
        self.lb_min_zoom.setObjectName("lb_min_zoom")
        self.gridLayout_3.addWidget(self.lb_min_zoom, 0, 0, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem5, 0, 1, 1, 1)
        self.sb_move_zoom = QtWidgets.QSpinBox(self.gb_zoom)
        self.sb_move_zoom.setObjectName("sb_move_zoom")
        self.gridLayout_3.addWidget(self.sb_move_zoom, 0, 3, 1, 1)
        self.verticalLayout.addWidget(self.gb_zoom)
        self.gb_focus = QtWidgets.QGroupBox(PositionControl)
        self.gb_focus.setAlignment(QtCore.Qt.AlignCenter)
        self.gb_focus.setCheckable(True)
        self.gb_focus.setObjectName("gb_focus")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.gb_focus)
        self.gridLayout_4.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.label_8 = QtWidgets.QLabel(self.gb_focus)
        self.label_8.setObjectName("label_8")
        self.gridLayout_4.addWidget(self.label_8, 1, 2, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem6, 1, 4, 1, 1)
        self.lb_max_focus = QtWidgets.QLabel(self.gb_focus)
        self.lb_max_focus.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lb_max_focus.setObjectName("lb_max_focus")
        self.gridLayout_4.addWidget(self.lb_max_focus, 1, 5, 1, 1)
        self.sl_pos_focus = QtWidgets.QSlider(self.gb_focus)
        self.sl_pos_focus.setOrientation(QtCore.Qt.Horizontal)
        self.sl_pos_focus.setObjectName("sl_pos_focus")
        self.gridLayout_4.addWidget(self.sl_pos_focus, 2, 0, 1, 6)
        self.lb_min_focus = QtWidgets.QLabel(self.gb_focus)
        self.lb_min_focus.setObjectName("lb_min_focus")
        self.gridLayout_4.addWidget(self.lb_min_focus, 1, 0, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem7, 1, 1, 1, 1)
        self.sb_move_focus = QtWidgets.QSpinBox(self.gb_focus)
        self.sb_move_focus.setObjectName("sb_move_focus")
        self.gridLayout_4.addWidget(self.sb_move_focus, 1, 3, 1, 1)
        self.verticalLayout.addWidget(self.gb_focus)
        spacerItem8 = QtWidgets.QSpacerItem(20, 150, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem8)

        self.retranslateUi(PositionControl)
        QtCore.QMetaObject.connectSlotsByName(PositionControl)

    def retranslateUi(self, PositionControl):
        _translate = QtCore.QCoreApplication.translate
        PositionControl.setWindowTitle(_translate("PositionControl", "Position Control"))
        self.gb_pan.setTitle(_translate("PositionControl", "Pan: 55.5"))
        self.lb_min_pan.setText(_translate("PositionControl", "-100"))
        self.lb_max_pan.setText(_translate("PositionControl", "100"))
        self.label.setText(_translate("PositionControl", "Move to:"))
        self.gb_tilt.setTitle(_translate("PositionControl", "Tilt: 101.2"))
        self.label_4.setText(_translate("PositionControl", "Move to:"))
        self.lb_min_tilt.setText(_translate("PositionControl", "-100"))
        self.lb_max_tilt.setText(_translate("PositionControl", "100"))
        self.gb_zoom.setTitle(_translate("PositionControl", "Zoom: 150"))
        self.label_6.setText(_translate("PositionControl", "Move to:"))
        self.lb_max_zoom.setText(_translate("PositionControl", "100"))
        self.lb_min_zoom.setText(_translate("PositionControl", "-100"))
        self.gb_focus.setTitle(_translate("PositionControl", "Focus: "))
        self.label_8.setText(_translate("PositionControl", "Move to:"))
        self.lb_max_focus.setText(_translate("PositionControl", "100"))
        self.lb_min_focus.setText(_translate("PositionControl", "-100"))

